<?php
/*
	WARNING! DO NOT EDIT THIS FILE!
	This file is part of the core Bizznis parent theme. 
	Please do all modifications in the form of a child theme.
*/

/**
 * Process user options to generate CSS needed to implement the choices.
 *
 * This function reads in the options from theme mods and determines whether a CSS rule is needed to implement an
 * option. CSS is only written for choices that are non-default in order to avoid adding unnecessary CSS. All options
 * are also filterable allowing for more precise control via a child theme or plugin.
 *
 * Note that this the CSS added only for the proof of concept. You should add your own CSS controls inside
 * your child themes, where you can and add much more CSS styling options.
 *
 * @since  1.1.1.
 *
 * @return void
 */
add_action( 'bizznis_css', 'bizznis_css_add_rules' );
function bizznis_css_add_rules() {

	/**
	 * Colors section
	 */
	// Get and escape options
	$color_primary   = bizznis_add_string_filter( 'maybe_hash_hex_color', get_theme_mod( 'bizznis_primary_color' ) );
	$color_secondary = bizznis_add_string_filter( 'maybe_hash_hex_color', get_theme_mod( 'bizznis_secondary_color' ) );
	$color_link      = bizznis_add_string_filter( 'maybe_hash_hex_color', get_theme_mod( 'bizznis_link_color' ) );
	$color_text      = bizznis_add_string_filter( 'maybe_hash_hex_color', get_theme_mod( 'bizznis_text_color' ) );
	$color_detail    = bizznis_add_string_filter( 'maybe_hash_hex_color', get_theme_mod( 'bizznis_detail_color' ) );
	
	// Primary color
	if ( $color_primary ) {
		bizznis_get_css()->add( array(
			'selectors'    => array( 
				'.color-primary-color',
				'.entry-title a',
				'.nav-secondary a',
			),
			'declarations' => array(
				'color' => $color_primary
			)
		) );
		bizznis_get_css()->add( array(
			'selectors'    => array(
				'.color-primary-background',
				'.nav-primary',
				'.footer-widgets',
				'.footer-creds',
			),
			'declarations' => array(
				'background-color' => $color_primary
			)
		) );
		bizznis_get_css()->add( array(
			'selectors'    => array(
				'input',
				'select',
				'textarea',
				'.color-primary-border',
				'.site-main',
				'.menu-bizznis .sub-menu a',
				'.nav-secondary',
				'.nav-header .sub-menu',
				'article.entry',
				'.archive-pagination',
				'.entry-pagination',
				'.entry-pings',
			),
			'declarations' => array(
				'border-color' => $color_primary
			)
		) );
	}
	
	// Secondary color
	if ( $color_secondary ) {
		bizznis_get_css()->add( array(
			'selectors'    => array( 
				'.nav-primary',
				'.nav-primary a',
				'.footer-widgets',
				'.footer-widgets a',
				'.footer-creds',
				'.footer-creds a',
			),
			'declarations' => array(
				'color' => $color_secondary
			)
		) );
		bizznis_get_css()->add( array(
			'selectors'    => array(
				'.author-box',
				'.archive-description',
				'li.comment',
				'.sidebar .widget',
				'.after-entry .widget',
			),
			'declarations' => array(
				'background-color' => $color_secondary
			)
		) );
		bizznis_get_css()->add( array(
			'selectors'    => array(
				'.footer-widgets',
			),
			'declarations' => array(
				'border-color' => $color_secondary
			),
			'media'        => 'screen and (min-width: 800px)' # Also define media query if needed
		) );
	}

	// Link color
	if ( $color_link ) {
		bizznis_get_css()->add( array(
			'selectors'    => array(
				'.bizznis_link_color',
				'a',
			),
			'declarations' => array(
				'color' => $color_link
			)
		) );
	}

	// Text color
	if ( $color_text ) {
		bizznis_get_css()->add( array(
			'selectors'    => array( 
				'.bizznis_text_color',
				'body',
			),
			'declarations' => array(
				'color' => $color_text
			)
		) );
	}

	// Detail color
	if ( $color_detail ) {
		bizznis_get_css()->add( array(
			'selectors'    => array(
				'.bizznis_detail_color-text',
				'.entry-meta',
				'.breadcrumb',
			),
			'declarations' => array(
				'color' => $color_detail
			)
		) );
	}
	
}